mailr13060 - /branches/gui_testing/gui/relax_gui.py


Others Months | Index by Date | Thread Index
>>   [Date Prev] [Date Next] [Thread Prev] [Thread Next]

Header


Content

Posted by edward on June 15, 2011 - 23:04:
Author: bugman
Date: Wed Jun 15 23:04:30 2011
New Revision: 13060

URL: http://svn.gna.org/viewcvs/relax?rev=13060&view=rev
Log:
Better handling of the return to the initial GUI screen.

This was broken on MS Windows.


Modified:
    branches/gui_testing/gui/relax_gui.py

Modified: branches/gui_testing/gui/relax_gui.py
URL: 
http://svn.gna.org/viewcvs/relax/branches/gui_testing/gui/relax_gui.py?rev=13060&r1=13059&r2=13060&view=diff
==============================================================================
--- branches/gui_testing/gui/relax_gui.py (original)
+++ branches/gui_testing/gui/relax_gui.py Wed Jun 15 23:04:30 2011
@@ -224,8 +224,9 @@
         sizer.Add(image, 0, wx.ALIGN_CENTER_HORIZONTAL, 0)
         sizer.AddStretchSpacer()
 
         # Re-perform the layout of the GUI elements, if needed.
         self.Layout()
+        self.Refresh()
 
 
     def close_analysis(self, event):
@@ -272,6 +273,10 @@
         if len(ds.relax_gui.analyses) == 0:
             # Reset the flag.
             self.init_state = True
+
+            # Delete the previous sizer.
+            old_sizer = self.GetSizer()
+            old_sizer.DeleteWindows()
 
             # Recreate the start screen.
             self.add_start_screen()
@@ -224,8 +224,9 @@
         sizer.AddStretchSpacer()
 
-        # Re-perform the layout of the GUI elements, if needed.
+        # Re-perform the layout of the GUI elements, and refresh.
         self.Layout()




Related Messages


Powered by MHonArc, Updated Thu Jun 16 11:40:02 2011